#[repr(u8)]pub enum Cachableen {
VAL0 = 0,
VAL1 = 1,
}Variants
VAL0 = 0
Disabled. When an AHB bus cacheable read access occurs, FlexSPI does not check whether it hit the AHB transmit buffer.
VAL1 = 1
Enabled. When an AHB bus cacheable read access occurs, FlexSPI first checks whether the access hit the AHB transmit buffer.
Implementations
Sourceimpl Cachableen
impl Cachableen