#[repr(u8)]pub enum RxClkSrcDiff {
VALUE0 = 0,
VALUE1 = 1,
}Variants
VALUE0 = 0
Use MCR0[RXCLKSRC] for Port A and Port B. MCR2[RXCLKSRC_B] is ignored and MCR0[RXCLKSRC] selects the Sample Clock source for Flash Reading of both ports A and B.
VALUE1 = 1
Use MCR0[RXCLKSRC] for Port A, and MCR2[RXCLKSRC_B] for Port B. MCR0[RXCLKSRC] selects the Sample Clock source for Flash Reading of port A (A_SCLK) and MCR2[RXCLKSRC_B] selects the Sample Clock source for Flash Reading of port B (B_SCLK).
Implementations
Sourceimpl RxClkSrcDiff
impl RxClkSrcDiff